import { ComponentProps, JSX, Ref } from 'solid-js';
import { Grammar, Theme } from './tm';

export { css } from './css';
/**********************************************************************************/
/**********************************************************************************/
type TmTextareaPropsBase = Omit<ComponentProps<'div'>, 'style' | 'onInput' | 'onScroll' | 'onKeyDown'> & Pick<ComponentProps<'textarea'>, 'onKeyDown' | 'onKeyPress' | 'onKeyUp' | 'onChange'>;
export interface TmTextareaProps extends TmTextareaPropsBase {
    /** If textarea is editable or not. */
    editable?: boolean;
    /** The grammar of the source code for syntax highlighting. */
    grammar: Grammar;
    /** Custom CSS properties to apply to the editor. */
    style?: JSX.CSSProperties;
    /** Ref to the internal html-textarea-element. */
    textareaRef?: Ref<HTMLTextAreaElement>;
    /** The theme to apply for syntax highlighting. */
    theme: Theme;
    /** The source code to be displayed and edited. */
    value: string;
    onScroll?: (event: Event & {
        currentTarget: HTMLDivElement;
    }) => void;
    onInput?: (event: InputEvent & {
        currentTarget: HTMLTextAreaElement;
    }) => void;
}
export declare function createTmTextarea(styles: Record<string, string>): (props: TmTextareaProps) => JSX.Element;
